@@ -1,7 +1,7 @@
 package Setup::File::Symlink;
 
-our $DATE = '2015-08-18'; # DATE
-our $VERSION = '0.27'; # VERSION
+our $DATE = '2015-09-04'; # DATE
+our $VERSION = '0.28'; # VERSION
 
 use 5.010001;
 use strict;
@@ -354,7 +354,7 @@ Setup::File::Symlink - Setup symlink (existence, target)
 
 =head1 VERSION
 
-This document describes version 0.27 of Setup::File::Symlink (from Perl distribution Setup-File-Symlink), released on 2015-08-18.
+This document describes version 0.28 of Setup::File::Symlink (from Perl distribution Setup-File-Symlink), released on 2015-09-04.
 
 =head1 SEE ALSO
 
@@ -367,13 +367,11 @@ L<Setup::File>
 
 =head2 ln_s(%args) -> [status, msg, result, meta]
 
-{en_US Create symlink}.
+Create symlink.
 
-{en_US 
 Fixed state: C<symlink> exists and points to C<target>.
 
 Fixable state: C<symlink> doesn't exist.
-}
 
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
@@ -384,11 +382,11 @@ Arguments ('*' denotes required arguments):
 
 =item * B<symlink> => I<str>
 
-{en_US Path to symlink}.
+Path to symlink.
 
 =item * B<target> => I<str>
 
-{en_US Path to target}.
+Path to target.
 
 =back
 
@@ -432,16 +430,14 @@ Return value:  (any)
 
 =head2 rmsym(%args) -> [status, msg, result, meta]
 
-{en_US Delete symlink}.
+Delete symlink.
 
-{en_US 
 Will not delete non-symlinks.
 
 Fixed state: C<path> doesn't exist.
 
 Fixable state: C<path> exists, is a symlink, (and if C<target> is defined, points
 to C<target>).
-}
 
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
@@ -454,7 +450,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<target> => I<str>
 
-{en_US Only delete if existing symlink has this target}.
+Only delete if existing symlink has this target.
 
 =back
 
@@ -498,9 +494,8 @@ Return value:  (any)
 
 =head2 setup_symlink(%args) -> [status, msg, result, meta]
 
-{en_US Setup symlink (existence, target)}.
+Setup symlink (existence, target).
 
-{en_US 
 When C<< should_exist=E<gt>1 >> (the default): On do, will create symlink which points to
 specified target. If symlink already exists but points to another target, it
 will be replaced with the correct symlink if C<replace_symlink> option is true.
@@ -512,7 +507,6 @@ symlink/file/dir if it was replaced during do.
 When C<< should_exist=E<gt>0 >>: On do, will remove symlink if it exists (and
 C<replace_symlink> is true). If C<replace_file>/C<replace_dir> is true, will also
 remove file/dir. On undo, will restore deleted symlink/file/dir.
-}
 
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
@@ -523,51 +517,41 @@ Arguments ('*' denotes required arguments):
 
 =item * B<create> => I<bool> (default: 1)
 
-{en_US Create if symlink doesn't exist}.
+Create if symlink doesn't exist.
 
-{en_US 
 If set to false, then setup will fail (412) if this condition is encountered.
-}
 
 =item * B<replace_dir> => I<bool> (default: 0)
 
-{en_US Replace if there is existing dir}.
+Replace if there is existing dir.
 
-{en_US 
 If set to false, then setup will fail (412) if this condition is encountered.
-}
 
 =item * B<replace_file> => I<bool> (default: 0)
 
-{en_US Replace if there is existing non-symlink file}.
+Replace if there is existing non-symlink file.
 
-{en_US 
 If set to false, then setup will fail (412) if this condition is encountered.
-}
 
 =item * B<replace_symlink> => I<bool> (default: 1)
 
-{en_US Replace previous symlink if it already exists but doesn't point to the wanted target}.
+Replace previous symlink if it already exists but doesn't point to the wanted target.
 
-{en_US 
 If set to false, then setup will fail (412) if this condition is encountered.
-}
 
 =item * B<should_exist> => I<bool> (default: 1)
 
-{en_US Whether symlink should exist}.
+Whether symlink should exist.
 
 =item * B<symlink>* => I<str>
 
-{en_US Path to symlink}.
+Path to symlink.
 
 =item * B<target> => I<str>
 
-{en_US Target path of symlink}.
+Target path of symlink.
 
-{en_US 
 Required, unless C<< should_exist =E<gt> 0 >>.
-}
 
 =back
 
